AppParams class
Config default value param for App
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- animationCurve ↔ Curve
-
Style curve
getter/setter pair
- animationDuration ↔ Duration
-
Default duration animation
getter/setter pair
- animationDurationFast ↔ Duration
-
Default duration animation fast
getter/setter pair
- animationDurationLow ↔ Duration
-
Default duration animation low
getter/setter pair
- delayInputEnd ↔ Duration
-
Default duration text field input end
getter/setter pair